Extract redundancy flag for subgroup combinations
Source:R/subgroup_search.R
extract_idx_flagredundancy.RdChecks if adding each factor to a subgroup reduces the sample size by at least rmin.
R/subgroup_search.R
extract_idx_flagredundancy.RdChecks if adding each factor to a subgroup reduces the sample size by at least rmin.