Learn R Programming

forestsearch (version 0.1.0)

find_leaf_split: Find the split that leads to a specific leaf node

Description

Identifies the split point that creates a given leaf node

Usage

find_leaf_split(tree, leaf_node)

Value

Character string with split expression or NULL

Arguments

tree

Policy tree object

leaf_node

Integer. Leaf node identifier