Get all combinations of subgroup factors up to maxk
Source:R/subgroup_search.R
get_combinations_info.RdGenerates all possible combinations of subgroup factors up to a specified maximum size.
R/subgroup_search.R
get_combinations_info.RdGenerates all possible combinations of subgroup factors up to a specified maximum size.