Run Single Consistency Split
Source:R/subgroup_consistency_helpers.R
run_single_consistency_split.RdPerforms one random 50/50 split and evaluates whether both halves meet the HR consistency threshold.
R/subgroup_consistency_helpers.R
run_single_consistency_split.RdPerforms one random 50/50 split and evaluates whether both halves meet the HR consistency threshold.