Sort Subgroups by Focus at consistency stage (consistency not available at this point)
Source:R/subgroup_consistency_helpers.R
sort_subgroups_preview.RdSorts a data.table of subgroup results according to the specified focus.
R/subgroup_consistency_helpers.R
sort_subgroups_preview.RdSorts a data.table of subgroup results according to the specified focus.