Learn R Programming

forestsearch (version 0.1.0)

summary.forestsearch: Summary Method for forestsearch Objects

Description

Provides a detailed summary of a ForestSearch analysis including input parameters, variable selection results, consistency evaluation, and the selected subgroup with key metrics.

Usage

# S3 method for forestsearch
summary(object, ...)

Value

Invisibly returns object.

Arguments

object

A forestsearch object returned by forestsearch.

...

Additional arguments (currently unused).