Create Reference Subgroup Indicator Columns
Source:R/plot_km_band_forestsearch.R
create_reference_subgroup_columns.RdCreates indicator columns (0/1) in the data frame for each reference subgroup based on the provided subset expressions.
R/plot_km_band_forestsearch.R
create_reference_subgroup_columns.RdCreates indicator columns (0/1) in the data frame for each reference subgroup based on the provided subset expressions.