Creates indicator columns (0/1) in the data frame for each reference subgroup based on the provided subset expressions.
create_reference_subgroup_columns(df, ref_subgroups, verbose = FALSE)List with modified df, cols, labels, and colors vectors.
Data frame to modify.
Named list of reference subgroup definitions.
Each element should have subset_expr and optionally
label and color.
Logical. Print diagnostic messages.