Fits a Cox model for a subgroup and returns estimate and standard error.
Usage
get_Cox_sg(df_sg, cox.formula, est.loghr = TRUE, cox_initial = log(1))Fits a Cox model for a subgroup and returns estimate and standard error.
get_Cox_sg(df_sg, cox.formula, est.loghr = TRUE, cox_initial = log(1))