Learn R Programming

forestsearch (version 0.1.0)

get_combinations_info: Get all combinations of subgroup factors up to maxk

Description

Generates all possible combinations of subgroup factors up to a specified maximum size.

Usage

get_combinations_info(L, maxk)

Value

List with max_count (total combinations) and indices_list (indices for each k).

Arguments

L

Integer. Number of subgroup factors.

maxk

Integer. Maximum number of factors in a combination.