Determines if a cut expression refers to a continuous variable. This optimized version avoids redundant lookups by using word boundary matching instead of partial string matching.
is_flag_continuous(thiscut, confounders.name, df, cont.cutoff)Logical; TRUE if continuous, FALSE otherwise.
Character string of the cut expression.
Character vector of confounder names.
Data frame.
Integer. Cutoff for continuous.